.. Copyright (C) 2020 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2020 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

See Also
========

- Manual pages: :man:`systemd-journald.service(8)`, :man:`journald.conf(5)`, :man:`journalctl(1)`

- `"Introducing the Journal" (2011) <https://docs.google.com/document/pub?id=1IC9yOXj7j6cdLLxWEBAGRL6wl97tFxgjLUEHIX3MSTs>`__

- `"systemd for System Administrators, Part XVII" (2012) <http://0pointer.de/blog/projects/journalctl.html>`__

- `LWN: "Forward Secure Sealing" (2012) <https://lwn.net/Articles/512895/>`__

- `Arch Linux Wiki: systemd/Journal <https://wiki.archlinux.org/index.php/Systemd/Journal>`__
